@@ -1,5 +1,8 @@
 # coding=utf-8
 """
+hangman.model
+~~~~~~~~~~~~~
+
 This module contains all of the game logic.
 """
 from __future__ import absolute_import
